@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2008-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -60,7 +60,7 @@ public:
     /**
      * Destructor
      */
-    ~KLineBufferedProcess() override;
+    ~KLineBufferedProcess() override = default;
 
     /**
      * Reads a line of text (excluding '\\n') from stdout.
